==> cc65-sources-2.10.1.tar.bz2: cc65-2.10.1/src/ld65/mapfile.h <==
/*****************************************************************************/
/*                                                                           */
/*				   mapfile.h				     */
/*                                                                           */
/*		     Map file creation for the ld65 linker		     */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/* (C) 1998-2003 Ullrich von Bassewitz                                       */
/*               Rmerstrasse 52                                             */
/*               D-70794 Filderstadt                                         */
/* EMail:        uz@cc65.org                                                 */
/*                                                                           */
/*                                                                           */
/* This software is provided 'as-is', without any expressed or implied       */
/* warranty.  In no event will the authors be held liable for any damages    */
/* arising from the use of this software.                                    */
/*                                                                           */
/* Permission is granted to anyone to use this software for any purpose,     */
/* including commercial applications, and to alter it and redistribute it    */
/* freely, subject to the following restrictions:                            */
/*                                                                           */
/* 1. The origin of this software must not be misrepresented; you must not   */
/*    claim that you wrote the original software. If you use this software   */
/*    in a product, an acknowledgment in the product documentation would be  */
/*    appreciated but is not required.                                       */
/* 2. Altered source versions must be plainly marked as such, and must not   */
/*    be misrepresented as being the original software.                      */
/* 3. This notice may not be removed or altered from any source              */
/*    distribution.                                                          */
/*                                                                           */
/*****************************************************************************/



#ifndef MAPFILE_H
#define MAPFILE_H



/*****************************************************************************/
/*  		 		     Code				     */
/*****************************************************************************/



void CreateMapFile (void);
/* Create a map file */

void CreateLabelFile (void);
/* Create a label file */



/* End of mapfile.h */

#endif

==> cc65-sources-2.13.3.tar.bz2: cc65-2.13.3/src/ld65/mapfile.h <==
/*****************************************************************************/
/*                                                                           */
/*				   mapfile.h				     */
/*                                                                           */
/*		     Map file creation for the ld65 linker		     */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/* (C) 1998-2005 Ullrich von Bassewitz                                       */
/*               Rmerstrasse 52                                             */
/*               D-70794 Filderstadt                                         */
/* EMail:        uz@cc65.org                                                 */
/*                                                                           */
/*                                                                           */
/* This software is provided 'as-is', without any expressed or implied       */
/* warranty.  In no event will the authors be held liable for any damages    */
/* arising from the use of this software.                                    */
/*                                                                           */
/* Permission is granted to anyone to use this software for any purpose,     */
/* including commercial applications, and to alter it and redistribute it    */
/* freely, subject to the following restrictions:                            */
/*                                                                           */
/* 1. The origin of this software must not be misrepresented; you must not   */
/*    claim that you wrote the original software. If you use this software   */
/*    in a product, an acknowledgment in the product documentation would be  */
/*    appreciated but is not required.                                       */
/* 2. Altered source versions must be plainly marked as such, and must not   */
/*    be misrepresented as being the original software.                      */
/* 3. This notice may not be removed or altered from any source              */
/*    distribution.                                                          */
/*                                                                           */
/*****************************************************************************/



#ifndef MAPFILE_H
#define MAPFILE_H



/*****************************************************************************/
/*  		 		     Data				     */
/*****************************************************************************/



/* Constants that may be used as arguments for CreateMapFile */
enum {
    LONG_MAPFILE,
    SHORT_MAPFILE
};



/*****************************************************************************/
/*  		 		     Code      				     */
/*****************************************************************************/



void CreateMapFile (int ShortMap);
/* Create a map file. If ShortMap is true, only the segment lists are
 * generated, not the import/export lists.
 */

void CreateLabelFile (void);
/* Create a label file */



/* End of mapfile.h */

#endif
